--[[

Switch Layer Plus
Based on Switch Commander v1 - Vernon Zehr (c)2012 - HubuMedia.com
Jeremy Jones (c)2015 - AnimeStudioTutor.com

Tested with Anime Studio Pro 11.1

Copy this script and icon into your custom content foder (Anime Studio Pro\scripts\tool\)
If you don't have one, Anime Studio > Help > Set Custom Content Folder...

Re-launch Anime Studio, select a switch layer, then select this tool from the 'Other' tools.
It works just like the normal switch tool, but now you can also use Alt + 0-9 to switch between layers in a switch group

]]--

-- **************************************************
-- Provide Moho with the name of this script object
-- **************************************************

ScriptName = "AST_Switch_Layer_Plus"

-- **************************************************
-- General information about this script
-- **************************************************

AST_Switch_Layer_Plus = {}
AST_Switch_Layer_Plus.BASE_STR = 2355

function AST_Switch_Layer_Plus:Name()
	return "Switch Layer Plus"
end
function AST_Switch_Layer_Plus:Version()
	return "1.1"
end
function AST_Switch_Layer_Plus:Description()
	return "Change the currently active layer in a switch group using <alt> + 0-9"
end
function AST_Switch_Layer_Plus:Creator()
	return "Vernon Zehr - HubuMedia.com, Jeremy Jones - AnimeStudioTutor.com"
end
function AST_Switch_Layer_Plus:UILabel()
	return "Switch Layer Plus ".. AST_Switch_Layer_Plus:Version()
end

-- ***************************************************
-- Recurring values
-- ***************************************************

AST_Switch_Layer_Plus.def= {}
AST_Switch_Layer_Plus.def.length = 0
AST_Switch_Layer_Plus.holder = {}

-- **************************************************
-- The guts of this script
-- **************************************************

function AST_Switch_Layer_Plus:IsEnabled(moho)
	local switchLayer = moho:LayerAsSwitch(moho.layer)
	if (switchLayer) then
		return true
	end
	return false
end
function AST_Switch_Layer_Plus:IsRelevant(moho)	
    local switchLayer = moho:LayerAsSwitch(moho.layer)   
    if (switchLayer) then
		return true
	end
	return false
end
function AST_Switch_Layer_Plus:OnMouseDown(moho, mouseEvent)
end
function AST_Switch_Layer_Plus:OnMouseMoved(moho, mouseEvent)
end
function AST_Switch_Layer_Plus:OnMouseUp(moho, mouseEvent)
end

-- **************************************************
-- Tool options - create and respond to tool's UI
-- **************************************************

AST_Switch_Layer_Plus.SELECTITEM = MOHO.MSG_BASE

function AST_Switch_Layer_Plus:DoLayout(moho, layout)	
	layout:AddChild(LM.GUI.StaticText(MOHO.Localize("/Scripts/Tool/SwitchLayer/ActiveChild=Switch Layer:")))	
    self.menu = LM.GUI.Menu(MOHO.Localize("/Scripts/Tool/SwitchLayer/SelectSwitchLayer=Select Switch Layer"))	
    self.popup = LM.GUI.PopupMenu(128, true)
	self.popup:SetMenu(self.menu)
	layout:AddChild(self.popup)    
	self.childName = LM.GUI.DynamicText("", 512)
	layout:AddChild(self.childName)
end
function AST_Switch_Layer_Plus:UpdateWidgets(moho)    
	local switchLayer = moho:LayerAsSwitch(moho.layer)	
    if (switchLayer == nil) then
		return
	end	
	for k in pairs (AST_Switch_Layer_Plus.holder) do
        AST_Switch_Layer_Plus.holder[k] = nil
    end    
    for i = 0, switchLayer:CountLayers() - 1 do
        table.insert(AST_Switch_Layer_Plus.holder,switchLayer:Layer(i):Name())        
	end    
    local kc = 47	
    self.menu:RemoveAllItems()
    for i = switchLayer:CountLayers() - 1, 0, -1 do
        self.menu:AddItem(switchLayer:Layer(i):Name(), 0, self.SELECTITEM + i)        
	end    
   self.menu:SetCheckedLabel(switchLayer:SwitchValues().value:Buffer(), true)
   self.popup:Redraw()    
end
function AST_Switch_Layer_Plus:HandleMessage(moho, view, msg)
    local switchLayer = moho:LayerAsSwitch(moho.layer)
    if (switchLayer == nil) then
		return
	end  
  if (msg >= self.SELECTITEM) then
		moho.document:PrepUndo(moho.layer)
		moho.document:SetDirty()
		switchLayer:SwitchValues():SetValue(moho.layerFrame, self.menu:FirstCheckedLabel())
		moho:NewKeyframe(CHANNEL_SWITCH)
        moho:UpdateUI()
	end  
end
function AST_Switch_Layer_Plus:OnKeyDown(moho, keyEvent, view)    

	local layer = moho.layer
	local switchLayer = moho:LayerAsSwitch(moho.layer)    
	local theKey = tonumber(keyEvent.key)

    if(theKey == nil) then
		return
	end
	if (theKey == 0) then
		theKey = 10
	end
	for i,v in pairs(AST_Switch_Layer_Plus.holder) do
		if (i > 10) then
			break
		end        
        AST_Switch_Layer_Plus.def[i] = v    
	end    
	if (keyEvent.altKey or keyEvent.ctrlKey and not keyEvent.shiftKey) then-- and theKey ~=nil) then
		local y = theKey
   
		if (y > 0 and y < 11) then    
			if(AST_Switch_Layer_Plus.def[theKey]) then               
				moho.document:PrepUndo(moho.layer)
				moho.document:SetDirty()
				switchLayer:SwitchValues():SetValue(moho.layerFrame, AST_Switch_Layer_Plus.def[theKey])
				self.popup:Redraw()
				moho:NewKeyframe(CHANNEL_SWITCH)
			end
		end
		layer:UpdateCurFrame(true)
		keyEvent.view:DrawMe()
	end
 end